@@ -207,7 +207,8 @@ class BaseTestCase(base.BaseTestCase):
         if output_id is not None:
             output_url = self.sahara.get_datasource(
                 data_source_id=output_id).url
-        pl = lambda x: self._inject_datasources_data(x, input_url, output_url)
+        pl = lambda x: (  # noqa: E731
+            self._inject_datasources_data(x, input_url, output_url))
         args = list(map(pl, configs.get('args', [])))
         configs['args'] = args
         return configs
@@ -573,11 +574,8 @@ class BaseTestCase(base.BaseTestCase):
         proxy_exist = False
 
         if self.network['public_network']:
-            if self.network['type'] == 'neutron':
-                floating_ip_pool = self.neutron.get_network_id(
-                    self.network['public_network'])
-            elif not self.network['auto_assignment_floating_ip']:
-                floating_ip_pool = self.network['public_network']
+            floating_ip_pool = self.neutron.get_network_id(
+                self.network['public_network'])
 
         node_groups = []
         for ng in self.testcase['node_group_templates']:
@@ -647,9 +645,8 @@ class BaseTestCase(base.BaseTestCase):
 
         kwargs.update(self.plugin_opts)
         kwargs['name'] = utils.rand_name(kwargs.get('name', 'ct'))
-        if self.network['type'] == 'neutron':
-            kwargs['net_id'] = self.neutron.get_network_id(
-                self.network['private_network'])
+        kwargs['net_id'] = self.neutron.get_network_id(
+            self.network['private_network'])
 
         return self.__create_cluster_template(**kwargs)
 
